@@ -1,15 +1,14 @@
 package Net::DNS::SPF::Expander;
-$Net::DNS::SPF::Expander::VERSION = '0.020';
-use Moose;
-use IO::All -utf8;
+$Net::DNS::SPF::Expander::VERSION = '0.021';
+use Moo;
+use MooX::Options;
+use Types::Standard qw/Str HashRef ArrayRef Maybe Int InstanceOf RegexpRef/;
 use Net::DNS::ZoneFile;
 use Net::DNS::Resolver;
-use MooseX::Types::IO::All 'IO_All';
+use Path::Tiny;
 use List::AllUtils qw(sum any part first uniq);
 use Scalar::Util ();
 
-with 'MooseX::Getopt';
-
 # ABSTRACT: Expands DNS SPF records, so you don't have to.
 # The problem is that you only get 10 per SPF records,
 # and recursions count against you. Your record won't
@@ -101,11 +100,13 @@ to expand. It must be a valid L<Net::DNS::Zonefile> zonefile.
 
 =cut
 
-has 'input_file' => (
+option 'input_file' => (
     is       => 'ro',
-    isa      => IO_All,
-    coerce   => 1,
+    isa      => InstanceOf ["Path::Tiny"],
+    coerce   => sub { path($_[0]) },
     required => 1,
+    format   => 's',
+    doc      => 'The file to be SPF-expanded'
 );
 
 =head2 output_file
@@ -115,11 +116,14 @@ onto the end of the original filename.
 
 =cut
 
-has 'output_file' => (
-    is         => 'ro',
-    isa        => 'Str',
-    lazy       => 1,
-    builder    => '_build_output_file',
+option 'output_file' => (
+    is      => 'ro',
+    isa     => InstanceOf ["Path::Tiny"],
+    coerce  => sub { path($_[0]) },
+    lazy    => 1,
+    builder => '_build_output_file',
+    format  => 's',
+    doc     => 'The destination file to write SPF-expanded records'
 );
 
 =head2 backup_file
@@ -131,9 +135,8 @@ onto the end of the original filename.
 
 has 'backup_file' => (
     is         => 'ro',
-    isa        => IO_All,
+    isa      => InstanceOf["Path::Tiny"],
     lazy       => 1,
-    coerce     => 1,
     builder    => '_build_backup_file',
 );
 
@@ -145,7 +148,7 @@ A list of nameservers that will be passed to the resolver.
 
 has 'nameservers' => (
     is  => 'ro',
-    isa => 'Maybe[ArrayRef]',
+    isa => Maybe[ArrayRef],
 );
 
 =head2 parsed_file
@@ -156,7 +159,7 @@ The L<Net::DNS::Zonefile> object created from the input_file.
 
 has 'parsed_file' => (
     is         => 'ro',
-    isa        => 'Net::DNS::ZoneFile',
+    isa        => InstanceOf['Net::DNS::ZoneFile'],
     lazy       => 1,
     builder    => '_build_parsed_file',
 );
@@ -170,7 +173,7 @@ a, mx, include, and redirect records. Configurable.
 
 has 'to_expand' => (
     is      => 'ro',
-    isa     => 'ArrayRef[RegexpRef]',
+    isa     => ArrayRef[RegexpRef],
     default => sub {
         [ qr/^a:/, qr/^mx/, qr/^include/, qr/^redirect/, ];
     },
@@ -185,7 +188,7 @@ we will copy ip4, ip6, ptr, and exists records. Configurable.
 
 has 'to_copy' => (
     is      => 'rw',
-    isa     => 'ArrayRef[RegexpRef]',
+    isa     => ArrayRef[RegexpRef],
     default => sub {
         [ qr/v=spf1/, qr/^ip4/, qr/^ip6/, qr/^ptr/, qr/^exists/, ];
     },
@@ -200,7 +203,7 @@ exp, v=spf1, and ~all.
 
 has 'to_ignore' => (
     is      => 'ro',
-    isa     => 'ArrayRef[RegexpRef]',
+    isa     => ArrayRef[RegexpRef],
     default => sub {
         [ qr/^v=spf1/, qr/^(\??)all/, qr/^exp/, qr/^~all/ ];
     },
@@ -216,7 +219,7 @@ from our length calculation.
 
 has 'maximum_record_length' => (
     is      => 'ro',
-    isa     => 'Int',
+    isa     => Int,
     default => sub {
         255 - length('v=spf1 ') - length(' ~all') - length('"') - length('"');
     },
@@ -230,10 +233,8 @@ Default time to live is 10 minutes. Configurable.
 
 has 'ttl' => (
     is      => 'ro',
-    isa     => 'Str',
-    default => sub {
-        '10M',;
-    },
+    isa     => Str,
+    default => sub { '10M' },
 );
 
 =head2 origin
@@ -245,7 +246,7 @@ or you can set it if you like.
 
 has 'origin' => (
     is         => 'ro',
-    isa        => 'Str',
+    isa        => Str,
     lazy       => 1,
     builder    => '_build_origin',
 );
@@ -261,7 +262,7 @@ found in the entire parsed_file.
 
 has '_resource_records' => (
     is         => 'ro',
-    isa        => 'Maybe[ArrayRef[Net::DNS::RR]]',
+    isa        => Maybe[ArrayRef[InstanceOf["Net::DNS::RR"]]],
     lazy       => 1,
     builder    => '_build__resource_records',
 );
@@ -275,7 +276,7 @@ records found in the entire parsed_file.
 
 has '_spf_records' => (
     is         => 'ro',
-    isa        => 'Maybe[ArrayRef[Net::DNS::RR]]',
+    isa        => Maybe[ArrayRef[InstanceOf["Net::DNS::RR"]]],
     lazy       => 1,
     builder    => '_build__spf_records',
 );
@@ -290,7 +291,7 @@ variables if you want to change the nameserver it uses.
 
 has '_resolver' => (
     is         => 'ro',
-    isa        => 'Net::DNS::Resolver',
+    isa        => InstanceOf["Net::DNS::Resolver"],
     lazy       => 1,
     builder    => '_build__resolver',
 );
@@ -325,7 +326,7 @@ They are alpha sorted in the final results for predictability in tests.
 
 has '_expansions' => (
     is         => 'ro',
-    isa        => 'HashRef',
+    isa        => HashRef,
     lazy       => 1,
     builder    => '_build__expansions',
 );
@@ -341,7 +342,7 @@ pieces.
 
 has '_lengths_of_expansions' => (
     is         => 'ro',
-    isa        => 'HashRef',
+    isa        => HashRef,
     lazy       => 1,
     builder    => '_build__lengths_of_expansions',
 );
@@ -354,7 +355,7 @@ What sort of records are SPF records? IN records.
 
 has '_record_class' => (
     is      => 'ro',
-    isa     => 'Str',
+    isa     => Str,
     default => sub {
         'IN',;
     },
@@ -407,9 +408,9 @@ Tack a ".bak" onto the end of the input_file.
 
 sub _build_backup_file {
     my $self = shift;
-    my $path = $self->input_file->filepath;
-    my $name = $self->input_file->filename;
-    return "${path}${name}.bak";
+    my $path = $self->input_file->parent;
+    my $name = $self->input_file->basename;
+    return path("${path}/${name}.bak");
 }
 
 =head2 _build_output_file
@@ -420,23 +421,23 @@ Tack a ".new" onto the end of the input_file.
 
 sub _build_output_file {
     my $self = shift;
-    my $path = $self->input_file->filepath;
-    my $name = $self->input_file->filename;
-    return "${path}${name}.new";
+    my $path = $self->input_file->parent;
+    my $name = $self->input_file->basename;
+    return path("${path}/${name}.new");
 }
 
 =head2 _build_parsed_file
 
-Turn the L<IO::All> filehandle into a L<Net::DNS::Zonefile>
+Turn the L<Path::Tiny> filehandle into a L<Net::DNS::Zonefile>
 object, so that we can extract the SPF records.
 
 =cut
 
 sub _build_parsed_file {
     my $self = shift;
-    my $path = $self->input_file->filepath;
-    my $name = $self->input_file->filename;
-    return Net::DNS::ZoneFile->new("${path}${name}");
+    my $path = $self->input_file->parent;
+    my $name = $self->input_file->basename;
+    return Net::DNS::ZoneFile->new("${path}/${name}");
 }
 
 =head2 _build_resource_records
@@ -505,10 +506,11 @@ Returns a scalar string of the data written to the file.
 
 sub write {
     my $self  = shift;
-    my $lines = $self->_new_records_lines;
-    io( $self->backup_file )->print( $self->input_file->all );
-    io( $self->output_file )->print(@$lines);
-    return join( '', @$lines );
+    my @new_lines = @{$self->_new_records_lines};
+    my @input_lines = $self->input_file->lines;
+    $self->backup_file->spew(@input_lines);
+    $self->output_file->spew(@new_lines);
+    return join( '', @new_lines );
 }
 
 =head2 new_spf_records
@@ -1039,7 +1041,7 @@ sub _new_records_lines {
             push @record_strings, @$record_string;
         }
     }
-    my @original_lines = $self->input_file->slurp;
+    my @original_lines = $self->input_file->lines;
     my @new_lines      = ();
     my @spf_indices;
     my $i = 0;
